@@ -17,7 +17,10 @@ class get:
         global ws
         if wsUrl != wsData["CURRENT_URL"]:
             wsData["CURRENT_URL"] = wsUrl
-            ws = create_connection(wsUrl, header=headers) #Måske kan den ikke være None
+            if headers == None:
+                ws = create_connection(wsUrl)
+            else:
+                ws = create_connection(wsUrl, header=headers)
 
         keys = []
         values = []
@@ -66,7 +69,10 @@ class post:
 
         if wsUrl != wsData["CURRENT_URL"]:
             wsData["CURRENT_URL"] = wsUrl
-            ws = create_connection(wsUrl, header=headers) #Måske kan den ikke være None
+            if headers == None:
+                ws = create_connection(wsUrl)
+            else:
+                ws = create_connection(wsUrl, header=headers)
 
         dataFormatted = JSON.dumps(data) if type(data) == dict else data if data != None else JSON.dumps(json)
         ws.send(dataFormatted)
